VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cGetVersion"
Attribute VB_GlobalNameSpace = True
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' ************************************************************
' Copyright  1999-2000 Slightly Tilted Software
' All rights reserved
' You're absolutely free to use these resources within your
'     own applications, but you may not redistribute them
'     (as source) in any manner whatsoever, whether for profit
'     or not.
' The only legitimate source for the original source code is
'     at the VBPJ site and my own web site at:
'     http://www.flash.net/~ljjohnsn/
' ************************************************************
Option Explicit
Option Compare Text
Option Base 0
DefLng A-Z

' --------------------------------------------
' API calls
' --------------------------------------------
Private Declare Function GetVersionEx Lib "kernel32" Alias "GetVersionExA" (lpVersionInformation As OSVERSIONINFO) As Long
Private Type OSVERSIONINFO
   dwOSVersionInfoSize                 As Long
   dwMajorVersion                      As Long
   dwMinorVersion                      As Long
   dwBuildNumber                       As Long
   dwPlatformId                        As Long
   szCSDVersion                        As String * 128
End Type

Private Enum enmPlatform
   VER_PLATFORM_UNKNOWN = -1&
   VER_PLATFORM_WIN32s = 0&
   VER_PLATFORM_WIN32_NT = 2&
   VER_PLATFORM_WIN32_WINDOWS = 1&
End Enum

Private m_typOSVersionInfo             As OSVERSIONINFO

Public Enum enmValidOSs
   Invalid_OS = 0&
   Valid_NT = 1&
   Valid_Win2000 = 2&
   Valid_Win98 = 3&
End Enum

Private m_blnIsValidOS                 As Boolean
Private m_strVersionText               As String
Private m_strErrMsg                    As String
Private m_typOS                        As enmValidOSs

Public Function IsValidOS() As Boolean
   IsValidOS = m_blnIsValidOS
End Function

Public Function TypeValidOS() As enmValidOSs
   TypeValidOS = m_typOS
End Function

Public Function OS_TypeError() As String
   OS_TypeError = m_strErrMsg
End Function

Public Function OS_VersionText() As String
   OS_VersionText = m_strVersionText
End Function

Private Sub GetOSVersion()
   Dim p_lngPos                        As Long
   Dim p_strVersion                    As String
   Dim p_lngMajorVer                   As Long
   Dim p_lngMinorVer                   As Long
   Dim p_intBuildNum                   As Integer
   Dim p_intServicePack                As Integer
   
   ' ------------------------------------------
   ' Set the length and make API call
   ' ------------------------------------------
   m_typOSVersionInfo.dwOSVersionInfoSize = Len(m_typOSVersionInfo)
   GetVersionEx m_typOSVersionInfo
   
   ' ------------------------------------------
   ' Trim the null from the Version string
   ' ------------------------------------------
   p_lngPos = InStr(1, m_typOSVersionInfo.szCSDVersion, Chr$(0))
   If p_lngPos > 0 Then
      p_strVersion = Trim$(Mid$(m_typOSVersionInfo.szCSDVersion, 1, p_lngPos - 1))
   Else
      p_strVersion = ""
   End If
   
   ' ------------------------------------------
   ' Get the details
   ' ------------------------------------------
   p_lngMajorVer = m_typOSVersionInfo.dwMajorVersion
   p_lngMinorVer = m_typOSVersionInfo.dwMinorVersion
   p_intBuildNum = WordLow(m_typOSVersionInfo.dwBuildNumber)
   If Len(p_strVersion) > 0 Then
      p_intServicePack = Val(Right$(p_strVersion, 1))
   Else
      p_intServicePack = 0
   End If
   
   ' ------------------------------------------
   ' Create a combined version string
   ' ------------------------------------------
   m_strVersionText = CStr(p_lngMajorVer) & "." & _
                      CStr(p_lngMinorVer)
   
   If p_intBuildNum > 0 Then
      m_strVersionText = m_strVersionText & " Build " & CStr(p_intBuildNum)
   End If
   
   If p_intServicePack > 0 Then
      m_strVersionText = m_strVersionText & " SP " & CStr(p_intServicePack)
   End If
   
   ' ------------------------------------------
   '
   ' ------------------------------------------
   Select Case m_typOSVersionInfo.dwPlatformId
      Case VER_PLATFORM_WIN32s
         m_strVersionText = "Win32s " & m_strVersionText
         
         ' ------------------------------------
         ' Not supported
         ' ------------------------------------
         m_strErrMsg = "You are running Win32s. This is not supported!"
         m_blnIsValidOS = False
         m_typOS = Invalid_OS
         
      Case VER_PLATFORM_WIN32_NT
         m_strVersionText = "Windows NT " & m_strVersionText
         
         ' ------------------------------------
         ' Pre-NT 4.0
         ' ------------------------------------
         If p_lngMajorVer < 4 Then
            m_strErrMsg = "You are running " & m_strVersionText & _
                          ". You must be running at least NT 4.0 with SP 4 or greater"
            m_blnIsValidOS = False
            m_typOS = Invalid_OS
            
         ' ------------------------------------
         ' NT 4.0
         ' ------------------------------------
         ElseIf p_lngMajorVer = 4 Then
            ' ---------------------------------
            ' It's NT 4.0, now need to check for
            '     SP4 or greater
            ' ---------------------------------
            If p_intServicePack < 4 Then
               m_strErrMsg = "You are running " & m_strVersionText & _
                             ". You must be running at least NT 4.0 with SP 4 or greater"
               m_blnIsValidOS = False
               m_typOS = Invalid_OS
            Else
               m_strErrMsg = ""
               m_blnIsValidOS = True
               m_typOS = Valid_NT
            End If
            
         ' ------------------------------------
         ' Win2000
         ' ------------------------------------
         ElseIf p_lngMajorVer = 5 Then
            ' ---------------------------------
            ' Win2000 -- check for build 2031
            '     or greater
            ' ---------------------------------
            If p_intBuildNum < 2031 Then
               m_strErrMsg = "You are running " & m_strVersionText & _
                             ". For Win2000, you must be running at least " & _
                             "build 2031 (Beta 3)."
               m_blnIsValidOS = False
               m_typOS = Invalid_OS
            Else
               m_strErrMsg = ""
               m_blnIsValidOS = True
               m_typOS = Valid_Win2000
            End If
         Else
            m_strErrMsg = "Unknown operating system: " & m_strVersionText
            m_blnIsValidOS = False
            m_typOS = Invalid_OS
         End If
         
      Case VER_PLATFORM_WIN32_WINDOWS
         m_strVersionText = "Windows 98 " & m_strVersionText
         m_strErrMsg = ""
         m_blnIsValidOS = True
         m_typOS = Valid_Win98
         
      Case Else
         m_strErrMsg = "Unknown operating system: " & m_strVersionText
         m_blnIsValidOS = False
         m_typOS = Invalid_OS

   End Select
   
End Sub

Private Function WordLow(ByVal xi_lngInput As Long) As Integer
   
   If (xi_lngInput And &HFFFF&) > &H7FFF Then
      WordLow = (xi_lngInput And &HFFFF&) - &H10000
   Else
      WordLow = xi_lngInput And &HFFFF&
   End If
   
End Function

Private Sub Class_Initialize()
   GetOSVersion
End Sub
